@@ -80,6 +80,10 @@ class BaseCommand(
     default_keyword
         The keyword to use when writing a message that does not specify a
         keyword.
+    silent
+        A silent command will call the actor ``write`` method with ``silent=True``,
+        which will update the internal model and record all the output replies but
+        will not write them to the users.
     loop
         The event loop.
 
@@ -96,6 +100,7 @@ class BaseCommand(
         status_callback: Optional[Callable[[CommandStatus], Any]] = None,
         call_now: bool = False,
         default_keyword: str = "text",
+        silent: bool = False,
         loop: Optional[asyncio.AbstractEventLoop] = None,
     ):
 
@@ -106,6 +111,8 @@ class BaseCommand(
         self.actor = actor
         self.parent = parent
 
+        self.silent = silent
+
         self._reply_callback = reply_callback
 
         self.default_keyword = default_keyword
@@ -265,11 +272,20 @@ class BaseCommand(
 
         command = self if not self.parent else self.parent
 
+        # If the parent has a command, do not output : or f since it would
+        # confuse the stream and potentially Tron.
+        if self.parent:
+            if message_code == ":":
+                message_code = "i"
+            elif message_code == "f":
+                message_code = "e"
+
         self.actor.write(
             message_code,
             message=message,
             command=command,
             broadcast=broadcast,
+            silent=self.silent,
             **kwargs,
         )
 
@@ -401,17 +417,20 @@ class TimedCommandList(list):
         """The polling loop."""
 
         current_time = time.time()
+        first_time = True
 
         while True:
 
             for timed_command in self:
                 elapsed = current_time - timed_command.last_run
-                if elapsed > timed_command.delay:
+                if first_time or elapsed > timed_command.delay:
                     timed_command_task = self.loop.create_task(
                         timed_command.run(self.actor)
                     )
                     timed_command_task.add_done_callback(timed_command.done)
 
+            first_time = False
+
             self._sleep_task = self.loop.create_task(asyncio.sleep(self.resolution))
 
             await self._sleep_task
@@ -457,21 +476,41 @@ class TimedCommand(object):
         The command string to run.
     delay
         How many seconds to wait between repeated calls.
+    first_silent
+        Runs the command in silent mode the first one (useful to internally update the
+        model).
+
     """
 
-    def __init__(self, command_string: str, delay: float = 1):
+    def __init__(self, command_string: str, delay: float = 1, first_silent=False):
 
         self.command_string = command_string
         self.delay = delay
 
         self.last_run = 0.0
+        self.is_running = False
+
+        self.first_silent = first_silent
 
     async def run(self, actor: clu.base.BaseActor):
         """Run the command."""
 
-        await Command(self.command_string, actor=actor, commander_id=actor.name).parse()
+        if self.is_running:
+            return
+
+        silent = True if self.first_silent and self.last_run == 0.0 else False
+
+        self.is_running = True
+
+        await Command(
+            self.command_string,
+            actor=actor,
+            commander_id=actor.name,
+            silent=silent,
+        ).parse()
 
     def done(self, task):
         """Marks the execution of a command."""
 
         self.last_run = time.time()
+        self.is_running = False
